Release Notes
=============

*fluxus* 1.0
------------

*fluxus* 1.0.1
~~~~~~~~~~~~~~

- BUILD: Add backward compatibility for Python 3.10.


*fluxus* 1.0.0
~~~~~~~~~~~~~~

- Initial release of *fluxus*.